#!/bin/bash

set -e  # Exit on error
clear

echo "*************************************"
echo "**  Reconfigure Wi-Fi Connections   **"
echo "*************************************"
echo ""

# Function to validate SSID and passwords
validate_input() {
  local input="$1"
  local type="$2"

  if [[ -z "$input" ]]; then
    echo "** Error: $type cannot be empty. Please try again. **"
    exit 1
  fi

  if [[ "$type" == "Password" && "${#input}" -lt 8 ]]; then
    echo "** Error: $type must be at least 8 characters. Please try again. **"
    exit 1
  fi
}

# Prompt for Wi-Fi details with validation
read -rp "** Enter the new Wi-Fi SSID you want the Mini-Pi to connect to: **  " ssidwifi
validate_input "$ssidwifi" "SSID"
read -rsp "** Enter the Wi-Fi password: **  " wifipassword
echo ""
validate_input "$wifipassword" "Password"

read -rp "** Enter the hotspot SSID to connect to: **  " hotspot
validate_input "$hotspot" "Hotspot SSID"
read -rsp "** Enter the hotspot password: **  " hotspotpassword
echo ""
validate_input "$hotspotpassword" "Hotspot Password"

echo ""
echo "***************************************"
echo "**   Writing to Wi-Fi settings file   **"
echo "***************************************"
echo ""

# Create a new wpa_supplicant configuration
wpa_file="./wpa_supplicant.conf"

cat <<EOL > "$wpa_file"
ctrl_interface=DIR=/var/run/wpa_supplicant GROUP=netdev
update_config=1
country=GB

network={
    ssid="$ssidwifi"
    psk="$wifipassword"
    key_mgmt=WPA-PSK
}

network={
    ssid="$hotspot"
    psk="$hotspotpassword"
    key_mgmt=WPA-PSK
}
EOL

# Secure file permissions for the generated file
chmod 600 "$wpa_file"

echo ""
echo "** Copying Wi-Fi configuration file to system location **"
echo ""

# Copy the configuration to the system location
#sudo cp "$wpa_file" /etc/wpa_supplicant/wpa_supplicant.conf

echo ""
echo "************************************************"
echo "**             Setup Complete                 **"
echo "************************************************"
echo ""

read -rp "** Wi-Fi settings are updated. Press Enter to reboot, or Ctrl+C to cancel. **"
sudo reboot
